@@ -13,7 +13,7 @@ package Movies::Organizer;
 use strict;
 use warnings;
 
-our $VERSION = '0.9';    # VERSION
+our $VERSION = '1.0';    # VERSION
 
 use Moo;
 use MooX::Options;
@@ -25,8 +25,10 @@ use File::Spec;
 use File::Copy;
 use Term::ReadLine;
 use Term::ReadLine::Perl;
-use IMDB::Film;
+use WWW::REST;
+use JSON::XS;
 use 5.010;
+use utf8;
 
 option 'from' => (
     doc => 'Source directory to organize',
@@ -95,11 +97,30 @@ has '_filter_words' => (
                 hdtv
                 hdrip
                 m2ts
+                s\d+
+                e\d+
+                s\d+e\d+
                 /
         ];
     },
 );
 
+has '_rs' => (
+    is      => 'ro',
+    default => sub {
+        my ($self) = @_;
+        my $rs = WWW::REST->new('http://imdbapi.org/');
+        $rs->dispatch(
+            sub {
+                my $self = shift;
+                croak $self->status_line if $self->is_error;
+                return decode_json( $self->content );
+            }
+        );
+        return $rs;
+    }
+);
+
 sub find_movies {
     my ($self) = @_;
 
@@ -128,19 +149,13 @@ SKIP_WORD: for my $word ( split( /\W+/x, $movie ) ) {
     return join( ' ', @words_ok );
 }
 
-sub fetch_movie {
-    my ( $self, $search ) = @_;
-
-    return IMDB::Film->new( crit => $search );
-}
-
 sub move_movie {
     my ( $self, %options ) = @_;
     my ( $term, $file, $imdb, $title, $season, $episode )
         = @options{qw/term file imdb title season episode/};
     my ( undef, undef, $movie ) = File::Spec->splitpath($file);
     my ( $season_part, $episode_part );
-    my $is_series = $imdb->kind =~ /series/;
+    my $is_series = $imdb->{type} eq 'TVS';
 
     if ($is_series) {
         $season_part  = sprintf( "S%02d", $season );
@@ -157,7 +172,8 @@ sub move_movie {
     $title =~ s/\s+(\w)/.\u$1/gx;    #replace space by dot
 
     #create destination
-    my $dest = File::Spec->catfile( $self->to, ucfirst( $imdb->kind ) );
+    my $dest = File::Spec->catfile( $self->to,
+        ucfirst( $imdb->{type} eq 'TVS' ? 'Tv series' : 'Movie' ) );
     if ($is_series) {
         $dest = File::Spec->catfile( $dest, $title, $season_part );
     }
@@ -174,7 +190,7 @@ sub move_movie {
         $ext = join( '.', $season_part . $episode_part, $ext );
     }
     else {
-        $ext = join( '.', "(" . $imdb->year . ")", $ext );
+        $ext = join( '.', "(" . $imdb->{year} . ")", $ext );
     }
     my $fdest = File::Spec->catfile( $dest, join( '.', $title, $ext ) );
 
@@ -216,7 +232,7 @@ sub run {
         say "Organize : $movie";
         my $another_episode;
         if (   defined $imdb
-            && $imdb->kind =~ /series/
+            && $imdb->{type} eq 'TVS'
             && $term->readline(
                 "is it another episode of " . $movie_title . " ? (Y/n) > ",
                 "y" ) eq "y"
@@ -232,34 +248,56 @@ sub run {
             while ( !defined $imdb ) {
                 my $imdb_search = $term->readline( "IMDB Search > ",
                     $self->filter_title($movie) );
-                $imdb = $self->fetch_movie($imdb_search);
-                $imdb = undef if !$imdb->status;
+                my $imdb_search_key = $imdb_search =~ /^tt\d+/x ? 'id' : 'q';
+
+                my $imdb_search_year
+                    = $term->readline("Movie/Series Year > ");
+
+                my @imdb_search_params = (
+                    $imdb_search_key => $imdb_search,
+                    limit            => 1,
+                    plot             => qw/full/,
+                    episode          => 0
+                );
+                push @imdb_search_params,
+                    year => $imdb_search_year,
+                    yg   => 1
+                    if $imdb_search_year ne '';
+
+                $imdb = $self->_rs->get(@imdb_search_params);
+
+                $imdb = undef if $imdb->{error};
                 if ($imdb) {
-                    say "Movie    : ", $imdb->title;
-                    say "Aka      : ", join( ', ', @{ $imdb->also_known_as } )
-                        if $self->with_aka;
-                    say "Kind     : ", $imdb->kind;
-                    say "Year     : ", $imdb->year;
-                    say "Plot     : ", $imdb->plot;
+                    say "Movie    : ", $imdb->{title};
+                    say "Aka      : ", join(
+                        ', ',
+                        map { utf8::encode($_); $_ } ## no critic (ProhibitComplexMappings)
+                            @{ $imdb->{also_known_as} // [] }
+                    ) if $self->with_aka;
+                    say "Kind     : ",
+                        $imdb->{type} eq 'TVS' ? 'Tv Serie' : 'Movie';
+                    say "Year     : ", $imdb->{year};
+                    say "Plot     : ", $imdb->{plot};
                     say "Directory: ",
-                        join( ', ',
-                        map { $_->{name} } @{ $imdb->directors } );
+                        join( ', ', @{ $imdb->{directors} // [] } );
                     say "Cast     : ",
-                        join( ', ',
-                        map { $_->{name} . "(" . $_->{role} . ")" }
-                            @{ $imdb->cast } );
-                    say "Genre    : ", join( ', ', @{ $imdb->genres } );
-                    say "Duration : ", $imdb->duration;
-                    say "Language : ", join( ', ', @{ $imdb->language } );
+                        join( ', ', @{ $imdb->{actors} // [] } );
+                    say "Genre    : ",
+                        join( ', ', @{ $imdb->{genres} // [] } );
+                    say "Duration : ",
+                        join( ', ', @{ $imdb->{runtime} // [] } );
+                    say "Language : ",
+                        join( ', ', @{ $imdb->{language} // [] } );
                     say "";
                     my $correct
                         = $term->readline( "Is it correct ? (Y/n) > ", "y" );
                     $imdb = undef unless $correct eq 'y';
                 }
             }
-            $movie_title = $imdb->title;
+            $movie_title = $imdb->{title};
             my @movie_titles = ($movie_title);
-            push @movie_titles, @{ $imdb->also_known_as } if $self->with_aka;
+            push @movie_titles, @{ $imdb->{also_known_as} // [] }
+                if $self->with_aka;
             if ( @movie_titles > 1 ) {
                 my $choice;
                 say "Select best title : ";
@@ -277,7 +315,7 @@ sub run {
                 say "";
             }
         }
-        if ( $imdb->kind =~ /series/ ) {
+        if ( $imdb->{type} eq 'TVS' ) {
             my $ok = 0;
             while ( !$ok || !defined $season || !defined $episode ) {
                 $ok++;
@@ -335,7 +373,7 @@ Movies::Organizer - Organize your movies using imdb
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -352,10 +390,6 @@ pass thought 'from' directory, and get all movies files. It will take file bigge
 
 Extract words from the file name, filter any common bad one, and return filtered title.
 
-=head2 fetch_movie
-
-Return IMDB search of your movie
-
 =head2 move_movie
 
 move the movie to the destination with the right name, that wil ease your classment with XMDB tools type.
